summaryrefslogtreecommitdiff
blob: c023335c3750da2e9b3d68a3c17e2956eb27bb1e (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
diff -Nru coda-6.9.3/coda-src/scripts/bldvldb.sh.in coda-6.9.3-gt/coda-src/scripts/bldvldb.sh.in
--- coda-6.9.3/coda-src/scripts/bldvldb.sh.in	2004-03-05 22:12:44.000000000 +0100
+++ coda-6.9.3-gt/coda-src/scripts/bldvldb.sh.in	2008-07-12 23:15:47.141740587 +0200
@@ -28,7 +28,7 @@
 fi
 
 if [ x${vicedir} = x ] ; then
-  vicedir=/vice
+  vicedir=/var/lib/vice
 fi
 
 THISHOST=`hostname | tr A-Z a-z`
diff -Nru coda-6.9.3/coda-src/scripts/coda-server-logrotate coda-6.9.3-gt/coda-src/scripts/coda-server-logrotate
--- coda-6.9.3/coda-src/scripts/coda-server-logrotate	2003-08-04 20:09:58.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/coda-server-logrotate	2008-07-12 23:15:53.629741210 +0200
@@ -3,7 +3,7 @@
 # Simple logrotation for Coda server logfiles
 #
 
-vicedir=/vice
+vicedir=/var/lib/vice
 . "`codaconfedit server.conf`"
 
 srvdir="${vicedir}/srv"
diff -Nru coda-6.9.3/coda-src/scripts/codastart coda-6.9.3-gt/coda-src/scripts/codastart
--- coda-6.9.3/coda-src/scripts/codastart	2006-09-19 19:48:57.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/codastart	2008-07-12 23:16:40.249741012 +0200
@@ -1,11 +1,11 @@
 #!/bin/sh
-if [ "`cat /vice/hostname`" = "`cat /vice/db/scm`" ]
+if [ "`cat /var/lib/vice/hostname`" = "`cat /var/lib/vice/db/scm`" ]
 then
     updatesrv &
     auth2 &
 else
     auth2 -chk &
 fi
-updateclnt -h `grep '' /vice/db/scm` &
+updateclnt -h `grep '' /var/lib/vice/db/scm` &
 startserver
 
diff -Nru coda-6.9.3/coda-src/scripts/createvol_rep.in coda-6.9.3-gt/coda-src/scripts/createvol_rep.in
--- coda-6.9.3/coda-src/scripts/createvol_rep.in	2007-06-26 18:18:28.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/createvol_rep.in	2008-07-12 23:17:29.601740626 +0200
@@ -32,7 +32,7 @@
 export PATH
 
 # load the server configuration file
-vicedir=/vice
+vicedir=/var/lib/vice
 . "`@sbindir@/codaconfedit server.conf`"
 
 if [ ! -f ${vicedir}/hostname -o ! -f ${vicedir}/db/scm ] ; then
diff -Nru coda-6.9.3/coda-src/scripts/purgevol_rep.in coda-6.9.3-gt/coda-src/scripts/purgevol_rep.in
--- coda-6.9.3/coda-src/scripts/purgevol_rep.in	2005-05-04 14:13:41.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/purgevol_rep.in	2008-07-12 23:18:23.829740822 +0200
@@ -24,7 +24,7 @@
 export PATH
 
 # load the server configuration file
-vicedir=/vice
+vicedir=/var/lib/vice
 . "`@sbindir@/codaconfedit server.conf`"
 
 SCM=`cat ${vicedir}/db/scm`
diff -Nru coda-6.9.3/coda-src/scripts/startserver.in coda-6.9.3-gt/coda-src/scripts/startserver.in
--- coda-6.9.3/coda-src/scripts/startserver.in	2004-10-26 23:36:43.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/startserver.in	2008-07-12 23:18:54.541741263 +0200
@@ -30,7 +30,7 @@
 fi
 
 if [ x${vicedir} = x ]; then
-  vicedir=/vice
+  vicedir=/var/lib/vice
 fi
 
 # Rotate logfiles
diff -Nru coda-6.9.3/coda-src/scripts/venus-setup.in coda-6.9.3-gt/coda-src/scripts/venus-setup.in
--- coda-6.9.3/coda-src/scripts/venus-setup.in	2007-08-10 20:02:24.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/venus-setup.in	2008-07-12 23:22:24.537741513 +0200
@@ -65,16 +65,16 @@
 #fi
 
 # default paths
-errorlog=/usr/coda/etc/console
-cachedir=/usr/coda/venus.cache
-checkpointdir=/usr/coda/spool
-logfile=/usr/coda/etc/venus.log
-marinersocket=/usr/coda/spool/mariner
-pid_file=/usr/coda/venus.cache/pid
-run_control_file=/usr/coda/venus.cache/VENUS_CTRL
-rvm_log=/usr/coda/LOG
-rvm_data=/usr/coda/DATA
-mountpoint=/coda
+errorlog=/var/lib/coda/etc/console
+cachedir=/var/lib/coda/venus.cache
+checkpointdir=/var/lib/coda/spool
+logfile=/var/lib/coda/etc/venus.log
+marinersocket=/var/lib/coda/spool/mariner
+pid_file=/var/lib/coda/venus.cache/pid
+run_control_file=/var/lib/coda/venus.cache/VENUS_CTRL
+rvm_log=/var/lib/coda/LOG
+rvm_data=/var/lib/coda/DATA
+mountpoint=/mnt/coda
 
 # override with user defined paths
 if [ x${conf} != x/dev/null ] ; then
@@ -224,8 +224,8 @@
 # next run will always initialize
 touch $cachedir/INIT
 
-if [ -f /usr/coda/etc/vstab ] ; then
-    echo "To avoid confusion, remove /usr/coda/etc/vstab, we have switched to"
+if [ -f /var/lib/coda/etc/vstab ] ; then
+    echo "To avoid confusion, remove /var/lib/coda/etc/vstab, we have switched to"
     echo "the /etc/coda/venus.conf file for configuring the client."
 fi
 
diff -Nru coda-6.9.3/coda-src/scripts/vice-setup-rvm.in coda-6.9.3-gt/coda-src/scripts/vice-setup-rvm.in
--- coda-6.9.3/coda-src/scripts/vice-setup-rvm.in	2006-09-19 19:35:02.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/vice-setup-rvm.in	2008-07-12 23:23:28.909741348 +0200
@@ -42,7 +42,7 @@
 #
 
 # defaults, will be overridden by settings in the server.conf file
-vicedir=/vice
+vicedir=/var/lib/vice
 
 prefix=@prefix@
 exec_prefix=@exec_prefix@
diff -Nru coda-6.9.3/coda-src/scripts/vice-setup-scm coda-6.9.3-gt/coda-src/scripts/vice-setup-scm
--- coda-6.9.3/coda-src/scripts/vice-setup-scm	2005-09-01 23:59:24.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/vice-setup-scm	2008-07-12 23:23:46.517741267 +0200
@@ -36,7 +36,7 @@
 . "`codaconfedit server.conf`"
 
 if [ x${vicedir} = x ] ; then
-  vicedir=/vice
+  vicedir=/var/lib/vice
 fi
 
 # current first maximum replicated volume id (0x7f000000)
diff -Nru coda-6.9.3/coda-src/scripts/vice-setup-srvdir coda-6.9.3-gt/coda-src/scripts/vice-setup-srvdir
--- coda-6.9.3/coda-src/scripts/vice-setup-srvdir	2005-09-01 23:59:24.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/vice-setup-srvdir	2008-07-12 23:24:28.813741293 +0200
@@ -28,7 +28,7 @@
 #
 # Configuration
 #
-vicedir=/vice
+vicedir=/var/lib/vice
 numservers=1
 . "`codaconfedit server.conf`"
 
@@ -73,15 +73,15 @@
     echo
     
     if [ $numservers -gt 1 ]; then
-	echon "Where shall we store your file data for server $n ($hn) [/vicepa]? "
+	echon "Where shall we store your file data for server $n ($hn) [/mnt/vicepa]? "
     else
-	echon 'Where shall we store your file data [/vicepa]? '
+	echon 'Where shall we store your file data [/mnt/vicepa]? '
     fi
     srvdir=
     read srvdir
 
     if [ "x$srvdir" = x ]; then
-	srvdir=/vicepa
+	srvdir=/mnt/vicepa
     fi
 
     # Create the directory if needed.  (Symlink is OK.)
diff -Nru coda-6.9.3/coda-src/scripts/vice-setup-user coda-6.9.3-gt/coda-src/scripts/vice-setup-user
--- coda-6.9.3/coda-src/scripts/vice-setup-user	2004-12-22 16:06:25.000000000 +0100
+++ coda-6.9.3-gt/coda-src/scripts/vice-setup-user	2008-07-12 23:24:51.889740616 +0200
@@ -31,7 +31,7 @@
 #
 # Configuration
 #
-vicedir=/vice
+vicedir=/var/lib/vice
 . "`codaconfedit server.conf`"
 
 # Set up password and group files for Coda
diff -Nru coda-6.9.3/coda-src/scripts/vice-setup.in coda-6.9.3-gt/coda-src/scripts/vice-setup.in
--- coda-6.9.3/coda-src/scripts/vice-setup.in	2007-07-20 23:34:49.000000000 +0200
+++ coda-6.9.3-gt/coda-src/scripts/vice-setup.in	2008-07-12 23:25:43.881740900 +0200
@@ -122,12 +122,12 @@
   fi
 fi
 
-echon "What is the root directory for your coda server(s)? [/vice] "
+echon "What is the root directory for your coda server(s)? [/var/lib/vice] "
 vicedir=""
 read vicedir
 
 if [ "x$vicedir" = x ] ; then
-   vicedir=/vice
+   vicedir=/var/lib/vice
 fi
 
 if [ $mkconf = 1 ] ; then
@@ -410,7 +410,7 @@
 	echo "That seems to have worked..."
 	echo "If you have a working Coda client you should now be able to"
 	echo "access the new Coda realm"
-	echo " - cfs lv /coda/${hn}/"
+	echo " - cfs lv /mnt/coda/${hn}/"
     fi
     echo
     echo "enjoy Coda."
@@ -444,7 +444,7 @@
 echo "After that, there is still some configuration needed on the SCM before"
 echo "this server can be started."
 echo
-echo "An entry for this host is needed in /vice/db/servers"
+echo "An entry for this host is needed in /var/lib/vice/db/servers"
 echo "Then all servers need to be shut down and restarted, as they need to"
 echo "know about the new server."
 echo "After all that it _should_ be ok to start the new server and create"
diff -Nru coda-6.9.3/coda-src/vice/server.conf.ex coda-6.9.3-gt/coda-src/vice/server.conf.ex
--- coda-6.9.3/coda-src/vice/server.conf.ex	2007-06-26 18:18:19.000000000 +0200
+++ coda-6.9.3-gt/coda-src/vice/server.conf.ex	2008-07-12 22:54:43.185740582 +0200
@@ -11,7 +11,7 @@
 #
 # Prefix of server tree
 #
-#vicedir=/vice
+vicedir=/var/lib/vice
 
 #
 # Should the server use private mmaps for RVM
diff -Nru coda-6.9.3/coda-src/venus/venus.conf.ex coda-6.9.3-gt/coda-src/venus/venus.conf.ex
--- coda-6.9.3/coda-src/venus/venus.conf.ex	2007-10-17 21:26:34.000000000 +0200
+++ coda-6.9.3-gt/coda-src/venus/venus.conf.ex	2008-07-12 22:53:43.817740642 +0200
@@ -20,7 +20,7 @@
 # Which file is used for realm lookups, before we look at dns SRV and A
 # records.
 #
-#realmtab=/etc/coda/realms
+realmtab=/etc/coda/realms
 
 #
 # What should the size of the local cache be in 1k blocks. If this is
@@ -55,9 +55,9 @@
 
 #
 # Which file should receive venus's stderr output.
-# (default is /usr/coda/etc/console).
+# (default is /var/lib/coda/etc/console).
 #
-#errorlog=/usr/coda/etc/console
+errorlog=/var/lib/coda/etc/console
 
 #
 # What is the uid of the primary user of this system. The primary user
@@ -72,43 +72,43 @@
 
 #
 # What are the locations of the rvm log and data files or partitions.
-# (default /usr/coda/{LOG,DATA}
+# (default /var/lib/coda/{LOG,DATA}
 #
 # CAUTION: these are _unrelated_ to the server's rvm log and data. Also
 # when specifying partitions, do NOT specify any partions which might
 # have an existing filesystem, as you WILL lose all data during
 # initialization.
 #
-#rvm_log=/usr/coda/LOG
-#rvm_data=/usr/coda/DATA
+rvm_log=/var/lib/coda/LOG
+rvm_data=/var/lib/coda/DATA
 
 #
 # Where should venus keep it's pool of cached files.
-# (default is /usr/coda/venus.cache)
+# (default is /var/lib/coda/venus.cache)
 #
-#cachedir=/usr/coda/venus.cache
+cachedir=/var/lib/coda/venus.cache
 
 #
 # Where should venus store snapshots of the modification logs. This is
 # primarily to provide some safe fallback when venus dies or messes up
 # the CML during reintegration. (default is /usr/coda/spool)
 #
-#checkpointdir=/usr/coda/spool
+checkpointdir=/var/lib/coda/spool
 
 #
 # Where does venus store it's pidfile
 #
-#pid_file=/usr/coda/venus.cache/pid
+pid_file=/var/lib/coda/venus.cache/pid
 
 #
 # What file does vutil use to control venus
 #
-#run_control_file=/usr/coda/venus.cache/VENUS_CTRL
+run_control_file=/var/lib/coda/venus.cache/VENUS_CTRL
 
 #
 # Venus log file
 #
-#logfile=/usr/coda/etc/venus.log
+logfile=/var/lib/coda/etc/venus.log
 
 #
 # Mariner socket,
@@ -116,7 +116,7 @@
 # codacon and spy use to talk to venus. On other platforms they will
 # connect to venus through tcp port 2430.
 #
-#marinersocket=/usr/coda/spool/mariner
+marinersocket=/var/lib/coda/spool/mariner
 
 #
 # Dont use RVM,
@@ -271,3 +271,11 @@
 #
 #isr=0
 
+# Mountpoint
+# Where the coda filesystem is mounted, many application still depend on
+# this being /coda. I am unsure whether it matters much on Windows95/98,
+# but we normally use N: for those.
+#
+#mountpoint=N:
+#mountpoint=/coda
+mountpoint=/mnt/coda
@@ -72,43 +72,43 @@
 # Where should venus store snapshots of the modification logs. This is
 # primarily to provide some safe fallback when venus dies or messes up
-# the CML during reintegration. (default is /usr/coda/spool)
+# the CML during reintegration. (default is /var/lib/coda/spool)
 #